/**
  * @file serialconfigdialog.h
  * @version 0.1
  * @date 17/02/2020
  * @author Sebastián Arriagada C.
  * @brief Definición de la clase serialConfigDialog que permite
  * cambiar la configuración de la comunicación serial.
  *
  */

#ifndef SERIALCONFIGDIALOG_H
#define SERIALCONFIGDIALOG_H

#include <QDialog>

namespace Ui {
class serialConfigDialog;
}

class serialConfigDialog : public QDialog
{
    Q_OBJECT

public:

    /**
     * @brief serialConfigDialog Constructor de la clase.
     * @param parent El padre, debe ser de tipo QWidget.
     */
    explicit serialConfigDialog(QWidget *parent = nullptr);

    /**
     * @brief ~serialConfigDialog Destructor de la clase.
     */
    ~serialConfigDialog();

    /**
     * @brief getBaudRate Devuelve el valor del Baud Rate ingresado por el usuario.
     * @return Entero con el valor del Baud rate ingresado.
     */
    int getBaudRate();

    /**
     * @brief getDatabit Devuelve la cantidad de bits por dato definidos por el usuario
     * @return Retorna un entero con la cantidad de bits por caracter enviado.\n Puede ser de 5 a 8.
     */
    int getDatabit();

    /**
     * @brief getParity Devuelve la forma en que se definirá la paridad definida por el usuario.
     * @return Retorna:\n 0 --> Sin bits de paridad agregados\n
     * 2 --> EvenParity\n
     * 3 --> OddParity\n
     * 4 --> SpaceParity\n
     * 5 --> MarkParity.
     */
    int getParity();

    /**
     * @brief getStopBit Devuelve el número de bits de parada ingresados por el usuario.
     * @return Retorna:\n 1 --> Un bits bit de parada agregado\n
     * 2 --> TwoStop\n
     * 3 --> OneAndHalfStop (solo para S.O. Windows).
     */
    int getStopBit();

    /**
     * @brief getFlowControl Devuelve el control de flujo definido por el usuario.
     * @return Retorna:\n 0 --> comunicación Sin Control de Flujo\n
     * 1 --> Comunicación con Control de Flujo por Hardware (RTS/CTS)\n
     * 2 --> Comunicación con Control de Flujo por Software (XON/XOFF)\n
     */
    int getFlowControl();

private:
    Ui::serialConfigDialog *ui;

private slots:

    /**
     * @brief on_buttonBox_accepted Para aceptar la configuración ingresada.
     */
    void on_buttonBox_accepted();

    /**
     * @brief on_buttonBox_rejected Para cancelar la configuración ingresada.
     */
    void on_buttonBox_rejected();
};

#endif // SERIALCONFIGDIALOG_H
